from setuptools import find_packages, setup

setup(name="frpython", version='1.4', description='Tentative de traduction de python en francais',
      author="Gatien Oudoire", packages=find_packages(), url="https://github.com/Gatien-Oudoire/python-fr", download_url="https://pypi.org/project/frpython")
