from .erreurs import *

from .decimaux import decimal
from .chaines import chaine
from typing import List, Tuple
from .entiers import entier
from .fonctions import *

def fr_python_info():
    try:
        imprimer("La librairie est prete")
    except:
        print("Erreur dans la librairie")


